# Signal, Pseudo Voigt IRF

When istrument response function is modeled to pseudo voigt profile, then since, pseudo voigt profile is just linear combination of cauchy and gaussian distribution, experimental signal is modeled to linear combination of ${Signal}_c$ and ${Signal}_g$.

\begin{equation*}
{Signal}_{pv}(t) = \eta {Signal}_c(t) + (1-\eta) {Signal}_g(t)
\end{equation*}
